@@ -283,7 +283,7 @@ class TerminalWindowHelper(object):
         image.set_from_icon_name("utilities-terminal", gtk.ICON_SIZE_MENU)
 
         bottom = window.get_bottom_panel()
-        bottom.add_item(self._panel, "GeditTerminalPanel", _("Terminal"), image)
+        bottom.add_item(self._panel, _("Terminal"), image)
 
     def deactivate(self):
         bottom = self._window.get_bottom_panel()
@@ -296,9 +296,10 @@ class TerminalWindowHelper(object):
         doc = self._window.get_active_document()
         if doc is None:
             return None
-        location = doc.get_location()
-        if location is not None and gedit.utils.location_has_file_scheme(location):
-            directory = location.get_parent()
+        uri = doc.get_uri()
+        if uri is not None and gedit.utils.uri_has_file_scheme(uri):
+            gfile = gio.File(uri)
+            directory = gfile.get_parent()
             return directory.get_path()
         return None
 
